'''
Created on Dec 19, 2016

@author: klaehn
'''
import paho.mqtt.client as mqtt_client

class Mqtt(object):
    ''' Wrapper class for mqtt communication '''
    def __init__(self, hostname, port=1883, keepalive=60, qos=2, retain=True):
        #pylint: disable=too-many-arguments
        self.__hostname = hostname
        self.__port = port
        self.__keepalive = keepalive
        self.__client = mqtt_client.Client()
        self.__is_connected = False
        self.__qos = qos
        self.__retain = retain

    def connect(self):
        ''' Connect to mqtt broker '''
        if not self.__is_connected:
            res = self.__client.connect(self.__hostname, self.__port, \
                                        self.__keepalive)
            if res != mqtt_client.MQTT_ERR_SUCCESS:
                return False
            res = self.__client.loop_start()
            if res != mqtt_client.MQTT_ERR_SUCCESS:
                return False
            self.__is_connected = True
            return True
        return False

    def disconnect(self):
        ''' Disconnect from mqtt broker '''
        if self.__is_connected:
            self.__client.loop_stop()
            self.__client.disconnect()
            self.__is_connected = False
            return True
        return False

    def transmit(self, topic, payload):
        ''' Transmit to subscriber via broker'''
        was_connected = True
        if not self.__is_connected:
            was_connected = False
            self.connect()
        result = self.__client.publish(topic, payload, self.__qos, self.__retain)
        if not was_connected:
            self.disconnect()
        if result == 0:
            return True
        return False
